summaryrefslogtreecommitdiffstats
path: root/kftpgrabber/src/widgets/browser/detailsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kftpgrabber/src/widgets/browser/detailsview.h')
-rw-r--r--kftpgrabber/src/widgets/browser/detailsview.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kftpgrabber/src/widgets/browser/detailsview.h b/kftpgrabber/src/widgets/browser/detailsview.h
index eb60b70..a06f16b 100644
--- a/kftpgrabber/src/widgets/browser/detailsview.h
+++ b/kftpgrabber/src/widgets/browser/detailsview.h
@@ -38,7 +38,7 @@
#include "browser/locationnavigator.h"
-#include <kfiledetailview.h>
+#include <tdefiledetailview.h>
#include <kdirlister.h>
namespace KFTPSession {
@@ -83,7 +83,7 @@ public:
* @param view Main view container
* @param session Current session
*/
- DetailsView(QWidget *parent, View *view, KFTPSession::Session *session);
+ DetailsView(TQWidget *parent, View *view, KFTPSession::Session *session);
/**
* Class destructor.
@@ -106,7 +106,7 @@ public:
* @param index Variable to save the current history position to
* @return Current history element list
*/
- const QValueList<LocationNavigator::Element> history(int &index) const;
+ const TQValueList<LocationNavigator::Element> history(int &index) const;
/**
* @overload
@@ -171,7 +171,7 @@ public:
*
* @param file Item's filename
*/
- KFileItem *fileItem(const QString &filename);
+ KFileItem *fileItem(const TQString &filename);
/**
* Changes item's colors in the list view. Note that this overrides any
@@ -181,7 +181,7 @@ public:
* @param text Text color
* @param background Background color
*/
- void setItemColor(KFileItem *item, const QColor &text, const QColor &background);
+ void setItemColor(KFileItem *item, const TQColor &text, const TQColor &background);
/**
* Changes item's visibility in the list view.
@@ -205,7 +205,7 @@ public:
*
* @param filename Item's filename
*/
- void markItem(const QString &filename);
+ void markItem(const TQString &filename);
/**
* Unmark all items.
@@ -242,7 +242,7 @@ public slots:
/**
* Returns the drag object to use for copy/paste and "drag and drop".
*/
- QDragObject *dragObject();
+ TQDragObject *dragObject();
protected:
/**
* Instruct the directory lister object to fetch the specified URL.
@@ -256,41 +256,41 @@ protected:
* This method gets called when the widget is resized. It is used for automatic
* resize handling.
*/
- void resizeEvent(QResizeEvent *event);
+ void resizeEvent(TQResizeEvent *event);
/**
* Returns true if the drop event should be accepted.
*/
- bool acceptDrag(QDropEvent *event) const;
+ bool acceptDrag(TQDropEvent *event) const;
/**
* Called when something acceptable gets dropped on us.
*/
- void contentsDropEvent(QDropEvent *event);
+ void contentsDropEvent(TQDropEvent *event);
private:
class ListViewItem : public KFileListViewItem {
public:
- ListViewItem(QListView *parent, KFileItem *fileItem);
+ ListViewItem(TQListView *parent, KFileItem *fileItem);
/**
* @overload
* Reimplemented from KListView to implement nicer items.
*/
- void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment);
/**
* Set a text color for this item.
*
* @param color Text color
*/
- void setColor(QColor color) { m_textColor = color; }
+ void setColor(TQColor color) { m_textColor = color; }
/**
* Set a background color for this item.
*
* @param color Background color
*/
- void setBackground(QColor color) { m_backgroundColor = color; }
+ void setBackground(TQColor color) { m_backgroundColor = color; }
/**
* Set marked state for this item.
@@ -304,8 +304,8 @@ private:
*/
bool marked() const { return m_marked; }
private:
- QColor m_textColor;
- QColor m_backgroundColor;
+ TQColor m_textColor;
+ TQColor m_backgroundColor;
bool m_marked;
};
@@ -313,7 +313,7 @@ private:
DirLister *m_dirLister;
LocationNavigator *m_navigator;
TreeView *m_treeView;
- QTimer *m_resizeTimer;
+ TQTimer *m_resizeTimer;
bool m_refreshing;
bool m_showHidden;
@@ -331,14 +331,14 @@ protected slots:
/**
* This slot gets called when an item has been renamed.
*/
- void slotItemRenamed(QListViewItem *item, const QString &name);
+ void slotItemRenamed(TQListViewItem *item, const TQString &name);
void slotContentsMoving(int x, int y);
/**
* This slot gets called when a context menu should be displayed.
*/
- void slotContextMenu(KListView*, QListViewItem *i, const QPoint &p);
+ void slotContextMenu(TDEListView*, TQListViewItem *i, const TQPoint &p);
/**
* This slot gets called when an item has been clicked.
@@ -256,41 +256,41 @@ protected:
/**
* @overload
- * Reimplemented from KListView to implement nicer items.
+ * Reimplemented from TDEListView to implement nicer items.
*/